@@ -19,11 +19,7 @@ else
     VERSION_ID=$( uname -r | sed "s/\([0-9\.]*\).*/\1/")
 fi
 
-# Make a lowercase equivalent of `${ID}`. Bash on macOS is 3.2, which does not
-# support `${foo,,}`.
-id=$(echo "${ID}" | tr '[:upper:]' '[:lower:]')
-
-if [[ ${id} == msys* ]]; then
+if [[ ${ID} == msys* ]]; then
     # MSYS2/MinGW doesn't have VERSION_ID in /etc/os-release
     VERSION_ID=$( uname -r )
 fi
@@ -31,9 +27,10 @@ fi
 # validate we have Git and echo version into log
 git --version
 
+GV_VERSION=$(python3 gen_version.py)
 META_DATA_DIR=Metadata/${ID}/${VERSION_ID}
 mkdir -p ${META_DATA_DIR}
-DIR=$(pwd)/Packages/${ID}/${VERSION_ID}
+DIR=$(pwd)/Packages/${CI_JOB_NAME}
 mkdir -p ${DIR}
 ARCH=$( uname -m )
 build_system=${build_system:-autotools}
@@ -46,32 +43,27 @@ if [ "${build_system}" = "cmake" ]; then
     cmake --build .
     cpack
     popd
-    if [[ ${id} == ubuntu* ]]; then
-        GV_VERSION=$(python3 gen_version.py)
-        mv build/Graphviz-${GV_VERSION}-Linux.deb ${DIR}/graphviz-${GV_VERSION}-cmake.deb
-    elif [[ ${id} == fedora* || ${id} == rocky* ]]; then
-        GV_VERSION=$(python3 gen_version.py)
-        mv build/Graphviz-${GV_VERSION}-Linux.rpm ${DIR}/graphviz-${GV_VERSION}-cmake.rpm
-    elif [[ ${id} == darwin* ]]; then
-        mv build/*.zip ${DIR}/
-    elif [[ ${id} == msys* ]]; then
-        mv build/*.zip ${DIR}/
-        mv build/*.exe ${DIR}/
-    elif [[ ${id} == cygwin* ]]; then
-        mv build/*.zip ${DIR}/
-        mv build/*.tar.bz2 ${DIR}/
+    if [[ ${ID} == ubuntu* ]]; then
+        mv build/Graphviz-${GV_VERSION}-Linux.deb ${DIR}/${ID}_${VERSION_ID}_graphviz-${GV_VERSION}-cmake.deb
+    elif [[ ${ID} == fedora* || ${ID} == rocky* ]]; then
+        mv build/Graphviz-${GV_VERSION}-Linux.rpm ${DIR}/${ID}_${VERSION_ID}_graphviz-${GV_VERSION}-cmake.rpm
+    elif [[ ${ID} == Darwin* ]]; then
+        mv build/Graphviz-${GV_VERSION}-Darwin.zip ${DIR}/${ID}_${VERSION_ID}_Graphviz-${GV_VERSION}-${ID}.zip
+    elif [[ ${ID} == msys* ]]; then
+        mv build/Graphviz-${GV_VERSION}-win64.zip ${DIR}/${ID}_${VERSION_ID}_Graphviz-${GV_VERSION}-win64.zip
+        mv build/Graphviz-${GV_VERSION}-win64.exe ${DIR}/${ID}_${VERSION_ID}_Graphviz-${GV_VERSION}-win64.exe
+    elif [[ ${ID} == CYGWIN* ]]; then
+        mv build/Graphviz-${GV_VERSION}-CYGWIN-1.tar.bz2 ${DIR}/${ID}_${VERSION_ID}_Graphviz-${GV_VERSION}-CYGWIN-1.tar.bz2
     else
         echo "Error: ID=${ID} is unknown" >&2
         exit 1
     fi
 elif [[ "${CONFIGURE_OPTIONS:-}" =~ "--enable-static" ]]; then
-    GV_VERSION=$(python3 gen_version.py)
     if [ "${use_autogen:-no}" = "yes" ]; then
         ./autogen.sh
         ./configure --disable-dependency-tracking ${CONFIGURE_OPTIONS:-} --prefix=$( pwd )/build | tee >(./ci/extract-configure-log.sh >${META_DATA_DIR}/configure.log)
         make
         make install
-        tar cf - -C build . | xz -9 -c - > ${DIR}/graphviz-${GV_VERSION}-${ARCH}.tar.xz
     else
         tar xfz graphviz-${GV_VERSION}.tar.gz
         pushd graphviz-${GV_VERSION}
@@ -81,29 +73,26 @@ elif [[ "${CONFIGURE_OPTIONS:-}" =~ "--enable-static" ]]; then
         popd
     fi
 else
-    GV_VERSION=$(python3 gen_version.py)
-    if [[ ${id} == ubuntu* ]]; then
+    if [[ ${ID} == ubuntu* ]]; then
         tar xfz graphviz-${GV_VERSION}.tar.gz
         (cd graphviz-${GV_VERSION}; fakeroot make -f debian/rules binary) | tee >(ci/extract-configure-log.sh >${META_DATA_DIR}/configure.log)
-        tar cf - *.deb *.ddeb | xz -9 -c - >${DIR}/graphviz-${GV_VERSION}-debs.tar.xz
-    elif [[ ${id} == fedora* || ${id} == rocky* ]]; then
+        tar cf - *.deb *.ddeb | xz -9 -c - >${DIR}/${ID}_${VERSION_ID}_graphviz-${GV_VERSION}-debs.tar.xz
+    elif [[ ${ID} == fedora* || ${ID} == rocky* ]]; then
         rm -rf ${HOME}/rpmbuild
         rpmbuild -ta graphviz-${GV_VERSION}.tar.gz | tee >(ci/extract-configure-log.sh >${META_DATA_DIR}/configure.log)
         pushd ${HOME}/rpmbuild/RPMS
         mv */*.rpm ./
-        tar cf - *.rpm | xz -9 -c - >${DIR}/graphviz-${GV_VERSION}-rpms.tar.xz
+        tar cf - *.rpm | xz -9 -c - >${DIR}/${ID}_${VERSION_ID}_graphviz-${GV_VERSION}-rpms.tar.xz
         popd
-    elif [[ ${id} == darwin* ]]; then
+    elif [[ ${ID} == Darwin* ]]; then
         tar xfz graphviz-${GV_VERSION}.tar.gz
         pushd graphviz-${GV_VERSION}
-        ./configure --disable-dependency-tracking --prefix=$( pwd )/build --with-quartz=yes
-        make
-        make install
-        python3 ../ci/make_relocatable.py $( pwd )/build
-        tar cfz ${DIR}/graphviz-${GV_VERSION}-${ARCH}.tar.gz --options gzip:compression-level=9 build
+        ./configure --disable-dependency-tracking --prefix=/usr/local/graphviz --with-quartz=yes
+        make pkg
+        cp graphviz-${ARCH}.pkg ${DIR}/${ID}_${VERSION_ID}_graphviz-${GV_VERSION}-${ARCH}.pkg
         popd
-    elif [[ ${id} == cygwin* || ${id} == msys* ]]; then
-        if [[ ${id} == msys* ]]; then
+    elif [[ ${ID} == CYGWIN* || ${ID} == msys* ]]; then
+        if [[ ${ID} == msys* ]]; then
             # ensure that MinGW tcl shell is used in order to find tcl functions
             CONFIGURE_OPTIONS="${CONFIGURE_OPTIONS:-} --with-tclsh=${MSYSTEM_PREFIX}/bin/tclsh86"
         else # Cygwin
@@ -115,7 +104,7 @@ else
             ./configure --disable-dependency-tracking ${CONFIGURE_OPTIONS:-} --prefix=$( pwd )/build | tee >(./ci/extract-configure-log.sh >${META_DATA_DIR}/configure.log)
             make
             make install
-            tar cf - -C build . | xz -9 -c - > ${DIR}/graphviz-${GV_VERSION}-${ARCH}.tar.xz
+            tar cf - -C build . | xz -9 -c - > ${DIR}/${ID}_${VERSION_ID}_graphviz-${GV_VERSION}-${ARCH}.tar.xz
         else
             tar xfz graphviz-${GV_VERSION}.tar.gz
             pushd graphviz-${GV_VERSION}
@@ -123,7 +112,7 @@ else
             make
             make install
             popd
-            tar cf - -C graphviz-${GV_VERSION}/build . | xz -9 -c - > ${DIR}/graphviz-${GV_VERSION}-${ARCH}.tar.xz
+            tar cf - -C graphviz-${GV_VERSION}/build . | xz -9 -c - > ${DIR}/${ID}_${VERSION_ID}_graphviz-${GV_VERSION}-${ARCH}.tar.xz
         fi
     else
         echo "Error: ID=${ID} is unknown" >&2
