@@ -8,6 +8,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include <assert.h>
 #include "topviewfuncs.h"
 #include <cgraph/cgraph.h>
@@ -223,7 +225,6 @@ static void renderSelectedNodes(Agraph_t * g)
     Agsym_t* l_color_attr = GG_nodelabelcolor(g);
     glCompColor c;
     int defaultNodeShape;
-    float nodeSize;
 
     glCompColorxlate(&c,agxget(g,l_color_attr));
 
@@ -247,7 +248,7 @@ static void renderSelectedNodes(Agraph_t * g)
 	    continue;
 	glColor4d(view->selectedNodeColor.R, view->selectedNodeColor.G,view->selectedNodeColor.B, view->selectedNodeColor.A);
 	pos = ND_A(v);
-	nodeSize = ND_size(v);
+	const double nodeSize = ND_size(v);
 
 	if (defaultNodeShape == 0) 
 	    glVertex3f(pos.x, pos.y, pos.z + 0.001f);
@@ -316,7 +317,7 @@ static void renderNodes(Agraph_t * g)
 	}
 	glColor4d(c.R,c.G,c.B,c.A);	    
 	const glCompPoint pos = getPointFromStr(agxget(v, pos_attr));
-	float nodeSize = l_float(v, size_attr, 0);
+	double nodeSize = l_float(v, size_attr, 0);
 
 	ND_A(v) = pos;
 
