@@ -8,8 +8,10 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include "viewportcamera.h"
-#include "gui.h"
+#include "gui/gui.h"
 #include <math.h>
 #include <glcomp/glcompbutton.h>
 #include <glcomp/glcomplabel.h>
