@@ -18,6 +18,8 @@
  * Updated by Emden Gansner
  */
 
+#include "config.h"
+
 #include <assert.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/ingraphs.h>
@@ -337,7 +339,7 @@ static void deriveClusters(Agraph_t *dg, Agraph_t *g) {
     if (is_a_cluster(subg)) {
       Agnode_t *const dn = agnode(dg, agnameof(subg), 1);
       agbindrec(dn, "nodeinfo", sizeof(nodeinfo_t), true);
-      ND_ptr(dn) = (Agobj_t *)subg;
+      ND_ptr(dn) = &subg->base;
       for (Agnode_t *n = agfstnode(subg); n; n = agnxtnode(subg, n)) {
         if (ND_ptr(n)) {
           fprintf(stderr,
@@ -345,7 +347,7 @@ static void deriveClusters(Agraph_t *dg, Agraph_t *g) {
                   "\"%s\" and \"%s\"\n",
                   agnameof(n), agnameof(subg), agnameof(ND_dn(n)));
         }
-        ND_ptr(n) = (Agobj_t *)dn;
+        ND_ptr(n) = &dn->base;
       }
     } else {
       deriveClusters(dg, subg);
@@ -367,8 +369,8 @@ static Agraph_t *deriveGraph(Agraph_t *g) {
       continue;
     Agnode_t *const dn = agnode(dg, agnameof(n), 1);
     agbindrec(dn, "nodeinfo", sizeof(nodeinfo_t), true);
-    ND_ptr(dn) = (Agobj_t *)n;
-    ND_ptr(n) = (Agobj_t *)dn;
+    ND_ptr(dn) = &n->base;
+    ND_ptr(n) = &dn->base;
   }
 
   for (Agnode_t *n = agfstnode(g); n; n = agnxtnode(g, n)) {
