@@ -7,11 +7,12 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <graphviz/cgraph.h>
 #include <graphviz/gvc.h>
 #include <graphviz/pack.h>
 #include <stdbool.h>
@@ -32,19 +33,19 @@ int main(int argc, char *argv[]) {
   aginit(g, AGRAPH, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
   aginit(g, AGNODE, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);
 
-  int ncc;
+  size_t ncc;
   graph_t **cc = ccomps(g, &ncc, NULL);
 
-  for (int i = 0; i < ncc; i++) {
+  for (size_t i = 0; i < ncc; i++) {
     graph_t *sg = cc[i];
-    nodeInduce(sg);
+    (void)graphviz_node_induce(sg, NULL);
     gvLayout(gvc, sg, "neato");
   }
   pack_graph(ncc, cc, g, 0);
 
   gvRender(gvc, g, "ps", stdout);
 
-  for (int i = 0; i < ncc; i++) {
+  for (size_t i = 0; i < ncc; i++) {
     graph_t *sg = cc[i];
     gvFreeLayout(gvc, sg);
     agdelete(g, sg);
