@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -15,25 +15,29 @@
  * convert a 0 terminated character constant string to an int
  */
 
+#include "config.h"
+
 #include <ast/ast.h>
 #include <limits.h>
+#include <stddef.h>
 
 int chrtoi(const char *s)
 {
     int c;
-    int n;
     int x;
     char *p;
 
     c = 0;
-    for (n = 0; n < sizeof(int) * CHAR_BIT; n += CHAR_BIT) {
+    for (size_t n = 0; n < sizeof(int) * CHAR_BIT; n += CHAR_BIT) {
 	switch (x = *((const unsigned char *) s++)) {
 	case '\\':
 	    x = chresc(s - 1, &p);
-	    s = (const char *) p;
+	    s = p;
 	    break;
 	case 0:
 	    return (c);
+	default: // nothing required
+	    break;
 	}
 	c = (c << CHAR_BIT) | x;
     }
