@@ -12,9 +12,12 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include <cgraph/cghdr.h>
-#include <cgraph/unreachable.h>
-#include <stddef.h>
+#include <stdlib.h>
+#include <util/alloc.h>
+#include <util/unreachable.h>
 
 int agdelete(Agraph_t * g, void *obj)
 {
@@ -54,7 +57,7 @@ int agrename(Agobj_t * obj, char *newname)
 	if (agmapnametoid(agroot(g), AGTYPE(obj), newname, &new_id, true) == 0)
 	    return FAILURE;
         /* obj* is unchanged, so no need to re agregister() */
-	if (agparent(g) && agidsubg(agparent(g), new_id, 0))
+	if (agparent(g) && agidsubg(agparent(g), new_id))
 	    return FAILURE;
 	agfreeid(g, AGRAPH, old_id);
 	AGID(g) = new_id;
@@ -200,9 +203,7 @@ Agraph_t *agraphof(void *obj)
 /* to manage disciplines */
 void agpushdisc(Agraph_t * g, Agcbdisc_t * cbd, void *state)
 {
-    Agcbstack_t *stack_ent;
-
-    stack_ent = AGNEW(g, Agcbstack_t);
+    Agcbstack_t *stack_ent = gv_alloc(sizeof(Agcbstack_t));
     stack_ent->f = cbd;
     stack_ent->state = state;
     stack_ent->prev = g->clos->cb;
@@ -224,7 +225,7 @@ int agpopdisc(Agraph_t * g, Agcbdisc_t * cbd)
 		stack_ent->prev = stack_ent->prev->prev;
 	}
 	if (stack_ent) {
-	    agfree(g, stack_ent);
+	    free(stack_ent);
 	    return SUCCESS;
 	}
     }
