@@ -8,36 +8,39 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include	<circogen/nodelist.h>
 #include	<circogen/circular.h>
 #include	<assert.h>
 #include	<limits.h>
 #include	<stddef.h>
 #include	<string.h>
+#include	<util/list.h>
 
 void appendNodelist(nodelist_t *list, size_t one, Agnode_t *n) {
-  assert(one <= nodelist_size(list));
+  assert(one <= LIST_SIZE(list));
 
   // expand the list by one element
-  nodelist_append(list, NULL);
+  LIST_APPEND(list, NULL);
 
   // shuffle everything past where we will insert
-  nodelist_sync(list);
-  size_t to_move = sizeof(node_t*) * (nodelist_size(list) - one - 1);
+  LIST_SYNC(list);
+  size_t to_move = sizeof(node_t*) * (LIST_SIZE(list) - one - 1);
   if (to_move > 0) {
-    memmove(nodelist_at(list, one + 1), nodelist_at(list, one), to_move);
+    memmove(LIST_AT(list, one + 1), LIST_AT(list, one), to_move);
   }
 
   // insert the new node
-  nodelist_set(list, one, n);
+  LIST_SET(list, one, n);
 }
 
 void realignNodelist(nodelist_t *list, size_t np) {
-  assert(np < nodelist_size(list));
+  assert(np < LIST_SIZE(list));
   for (size_t i = np; i != 0; --i) {
     // rotate the list by 1
-    node_t *const head = nodelist_pop_front(list);
-    nodelist_push_back(list, head);
+    node_t *const head = LIST_POP_FRONT(list);
+    LIST_PUSH_BACK(list, head);
   }
 }
 
@@ -45,10 +48,10 @@ void
 insertNodelist(nodelist_t * list, Agnode_t * cn, Agnode_t * neighbor,
 	       int pos)
 {
-  nodelist_remove(list, cn);
+  LIST_REMOVE(list, cn);
 
-  for (size_t i = 0; i < nodelist_size(list); ++i) {
-    Agnode_t *here = nodelist_get(list, i);
+  for (size_t i = 0; i < LIST_SIZE(list); ++i) {
+    Agnode_t *here = LIST_GET(list, i);
     if (here == neighbor) {
       if (pos == 0) {
         appendNodelist(list, i, cn);
@@ -63,23 +66,23 @@ insertNodelist(nodelist_t * list, Agnode_t * cn, Agnode_t * neighbor,
 /// attach l2 to l1.
 static void concatNodelist(nodelist_t * l1, nodelist_t * l2)
 {
-  for (size_t i = 0; i < nodelist_size(l2); ++i) {
-    nodelist_append(l1, nodelist_get(l2, i));
+  for (size_t i = 0; i < LIST_SIZE(l2); ++i) {
+    LIST_APPEND(l1, LIST_GET(l2, i));
   }
 }
 
 void reverseAppend(nodelist_t * l1, nodelist_t * l2)
 {
-    nodelist_reverse(l2);
+    LIST_REVERSE(l2);
     concatNodelist(l1, l2);
-    nodelist_free(l2);
+    LIST_FREE(l2);
 }
 
 #ifdef DEBUG
 void printNodelist(nodelist_t * list)
 {
-    for (size_t i = 0; i < nodelist_size(list); ++i) {
-      fprintf(stderr, "%s ", agnameof(nodelist_get(list, i)));
+    for (size_t i = 0; i < LIST_SIZE(list); ++i) {
+      fprintf(stderr, "%s ", agnameof(LIST_GET(list, i)));
     }
     fputs("\n", stderr);
 }
