@@ -13,6 +13,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include <stdio.h>
 
 #include <math.h>
@@ -30,7 +32,7 @@
 #include <util/strcasecmp.h>
 #include <util/unreachable.h>
 
-static char* colorscheme;
+static _Thread_local char *colorscheme;
 
 static void hsv2rgb(double h, double s, double v,
 			double *r, double *g, double *b)
