@@ -3,10 +3,13 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
+
+#include "config.h"
+
 #include <sparse/general.h>
 #include <sparse/QuadTree.h>
 #include <edgepaint/lab.h>
@@ -16,6 +19,8 @@
 #include <string.h>
 #include <sparse/color_palette.h>
 #include <edgepaint/lab_gamut.h>
+#include <util/alloc.h>
+#include <util/prisize_t.h>
 
 color_rgb color_rgb_init(double r, double g, double b){
   color_rgb rgb;
@@ -70,13 +75,8 @@ color_lab RGB2LAB(color_rgb color){
 
 void LAB2RGB_real_01(double *color){
   /* convert an array[3] of LAB colors to RGB between 0 to 1, in place */
-  color_rgb rgb;
-  color_lab lab;
-
-  lab.l = color[0];
-  lab.a = color[1];
-  lab.b = color[2];
-  rgb = LAB2RGB(lab);
+  const color_lab lab = {.l = color[0], .a = color[1], .b = color[2]};
+  const color_rgb rgb = LAB2RGB(lab);
   color[0] = rgb.r/255;
   color[1] = rgb.g/255;
   color[2] = rgb.b/255;
@@ -138,38 +138,32 @@ color_rgb XYZ2RGB(color_xyz color){
   return color_rgb_init(r, g, b);
 }
 
-double *lab_gamut(const char *lightness, int *n){
+double *lab_gamut(const int *lightness, int *n) {
   /* give a list of n points  in the file defining the LAB color gamut.
-     lightness is a string of the form 0,70, or NULL.
    */
   double *xx, *x;
 
-  int l1 = 0, l2 = 70;
-
-
-  if (lightness && sscanf(lightness, "%d,%d", &l1, &l2) == 2){
-    if (l1 < 0) l1 = 0;
-    if (l2 > 100) l2 = 100;
-    if (l1 > l2) l1 = l2;
-  } else {
-    l1 = 0; l2 = 70;
-  }
+  int l1 = lightness[0];
+  int l2 = lightness[1];
 
+  if (l1 < 0) l1 = 0;
+  if (l2 > 100) l2 = 100;
+  if (l1 > l2) l1 = l2;
 
   if (Verbose)
     fprintf(stderr,"LAB color lightness range = %d,%d\n", l1, l2);
 
   if (Verbose)
-    fprintf(stderr,"size of lab gamut = %d\n", lab_gamut_data_size);
+    fprintf(stderr,"size of lab gamut = %" PRISIZE_T "\n", lab_gamut_data_size);
 
   // each L* value can be paired with 256 a* values and 256 b* values, so
   // compute the maximum number of doubles we will need to span the space
   size_t m = ((size_t)l2 - (size_t)l1 + 1) * 256 * 256 * 3;
 
-  x = malloc(sizeof(double)*m);
+  x = gv_calloc(m, sizeof(double));
   xx = x;
   *n = 0;
-  for (size_t i = 0; i < (size_t)lab_gamut_data_size; i += 4){
+  for (size_t i = 0; i < lab_gamut_data_size; i += 4){
     if (lab_gamut_data[i] >= l1 && lab_gamut_data[i] <= l2){
       int b_lower = lab_gamut_data[i + 2];
       int b_upper = lab_gamut_data[i + 3];
@@ -186,7 +180,8 @@ double *lab_gamut(const char *lightness, int *n){
   return x;
 }
 
-QuadTree lab_gamut_quadtree(const char *lightness, int max_qtree_level){
+QuadTree lab_gamut_quadtree(const int *lightness,
+                            int max_qtree_level) {
   /* read the color gamut points list in the form "x y z\n ..." and store in the octtree */
   int n;
   double *x = lab_gamut(lightness, &n);
@@ -194,7 +189,7 @@ QuadTree lab_gamut_quadtree(const char *lightness, int max_qtree_level){
   int dim = 3;
 
   if (!x) return NULL;
-  qt = QuadTree_new_from_point_list(dim, n, max_qtree_level, x, NULL);
+  qt = QuadTree_new_from_point_list(dim, n, max_qtree_level, x);
 
 
   free(x);
@@ -211,33 +206,27 @@ static void lab_interpolate(color_lab lab1, color_lab lab2, double t, double *co
   colors[2] = lab1.b + t*(lab2.b - lab1.b);
 }
 
-void color_blend_rgb2lab(char *color_list, const int maxpoints, double **colors0){
+double *color_blend_rgb2lab(const char *color_list, const int maxpoints) {
   /* give a color list of the form "#ff0000,#00ff00,...", get a list of around maxpoints
      colors in an array colors0 of size [maxpoints*3] of the form {{l,a,b},...}.
-     If *colors0 is NULL, it will be allocated.
      color_list: either "#ff0000,#00ff00,...", or "pastel"
   */
 
   int nc = 1, r, g, b, i, ii, jj, cdim = 3;
-  char *cl;
-  color_lab *lab;
   color_rgb rgb;
-  double *dists, step, dist_current;
-  double *colors = NULL;
-  char *cp;
-
-  cp = color_palettes_get(color_list);
+  double step, dist_current;
+  const char *cp = color_palettes_get(color_list);
   if (cp){
     color_list = cp;
   }
 
-  if (maxpoints <= 0) return;
+  if (maxpoints <= 0) return NULL;
 
-  cl = color_list;
+  const char *cl = color_list;
   while ((cl=strchr(cl, ',')) != NULL){
     cl++; nc++;
   }
-  lab = malloc(sizeof(color_lab)*MAX(nc,1));
+  color_lab *lab = gv_calloc(MAX(nc, 1), sizeof(color_lab));
 
   cl = color_list - 1;
   nc = 0;
@@ -248,7 +237,7 @@ void color_blend_rgb2lab(char *color_list, const int maxpoints, double **colors0
     lab[nc++] = RGB2LAB(rgb);
   } while ((cl=strchr(cl, ',')) != NULL);
 
-  dists = malloc(sizeof(double)*MAX(1, nc));
+  double *dists = gv_calloc(MAX(1, nc), sizeof(double));
   dists[0] = 0;
   for (i = 0; i < nc - 1; i++){
     dists[i+1] = lab_dist(lab[i], lab[i+1]);
@@ -260,10 +249,7 @@ void color_blend_rgb2lab(char *color_list, const int maxpoints, double **colors0
   if (Verbose)
     fprintf(stderr,"sum = %f\n", dists[nc-1]);
 
-  if (!(*colors0)){
-    *colors0 = malloc(sizeof(double)*maxpoints*cdim);
-  }
-  colors = *colors0; 
+  double *colors = gv_calloc(maxpoints * cdim, sizeof(double));
   if (maxpoints == 1){
     colors[0] = lab[0].l;
     colors[1] = lab[0].a;
@@ -273,14 +259,17 @@ void color_blend_rgb2lab(char *color_list, const int maxpoints, double **colors0
     ii = 0; jj = 0; dist_current = 0;
     while (dists[jj] < dists[ii] + step) jj++;
     
+    double *colors_ptr = colors;
     for (i = 0; i < maxpoints; i++){
-      lab_interpolate(lab[ii], lab[jj], (dist_current - dists[ii])/MAX(0.001, (dists[jj] - dists[ii])), colors);
+      lab_interpolate(lab[ii], lab[jj], (dist_current - dists[ii]) /
+                      MAX(0.001, (dists[jj] - dists[ii])), colors_ptr);
       dist_current += step;
-      colors += cdim;
+      colors_ptr += cdim;
       if (dist_current > dists[jj]) ii = jj;
       while (jj < nc -1 && dists[jj] < dists[ii] + step) jj++;
     }
   }
   free(dists);
   free(lab);
+  return colors;
 }
