@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -15,7 +15,10 @@
  * expression library
  */
 
+#include "config.h"
+
 #include <expr/exlib.h>
+#include <util/gv_ctype.h>
 
 /*
  * copy input token error context into buf of n chars and reset the context
@@ -36,7 +39,7 @@ excontext(Expr_t* p, char* buf, int n)
 		if (p->linewrap)
 		{
 			t = p->linep + 1;
-			while (t < &p->line[sizeof(p->line)] && isspace(*t))
+			while (t < &p->line[sizeof(p->line)] && gv_isspace(*t))
 				t++;
 			if ((n = (sizeof(p->line) - (t - (p->linep + 1))) - (e - s)) > 0)
 			{
@@ -50,7 +53,7 @@ excontext(Expr_t* p, char* buf, int n)
 		t = p->line;
 		if (p->linewrap)
 			p->linewrap = 0;
-		else while (t < p->linep && isspace(*t))
+		else while (t < p->linep && gv_isspace(*t))
 			t++;
 		if ((n = (p->linep - t) - (e - s)) > 0)
 			t += n;
