@@ -3,20 +3,22 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #pragma once
 
+#include <stddef.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 #include <common/render.h>
 
-    extern graph_t **findCComp(graph_t *, int *, int *);
+graph_t **findCComp(graph_t *, size_t *, int *);
 
 #ifdef __cplusplus
 }
