@@ -1,14 +1,14 @@
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
-#ifndef GLCOMPLABEL_H
-#define GLCOMPLABEL_H
+
+#pragma once
 
 #include <glcomp/glcompdefs.h>
 
@@ -16,13 +16,8 @@
 extern "C" {
 #endif
 
-    extern glCompLabel *glCompLabelNew(glCompObj * par, GLfloat x,
-				       GLfloat y, char *text);
-
-/*events*/
-    extern int glCompLabelDraw(glCompLabel * p);
+glCompLabel *glCompLabelNew(void *par, char *text);
 
 #ifdef __cplusplus
 }
 #endif
-#endif
