@@ -14,6 +14,8 @@
  *
  */
 
+#include "config.h"
+
 #include <gvpr/gprstate.h>
 #include <ast/error.h>
 #include <stdbool.h>
@@ -46,8 +48,7 @@ Gpr_t *openGPRState(gpr_info* info)
     state->tvnext = 0;
     state->tvedge = 0;
     state->outFile = info->outFile;
-    state->argc = info->argc;
-    state->argv = info->argv;
+    state->args = info->args;
     state->errf = info->errf;
     state->flags = info->flags;
 
