@@ -8,6 +8,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include <neatogen/matrix_ops.h>
 #include <neatogen/conjgrad.h>
 #include <stdbool.h>
@@ -129,7 +131,7 @@ int conjugate_gradient_f
 	    vectors_scalar_mult(n, Ap, alpha, Ap);
 	    vectors_subtraction(n, r, Ap, r);	/* fast computation of r, the residual */
 
-	    /* Alternaive accurate, but slow, computation of the residual - r */
+	    // Alternative accurate, but slow, computation of the residual - r
 	    /* right_mult_with_vector(A, n, x, Ax); */
 	    /* vectors_subtraction(n,b,Ax,r); */
 
@@ -162,7 +164,7 @@ conjugate_gradient_mkernel(float *A, float *x, float *b, int n,
 {
     /* Solves Ax=b using Conjugate-Gradients method */
     /* A is a packed symmetric matrix */
-    /* matrux A is "packed" (only upper triangular portion exists, row-major); */
+    // matrix A is “packed” (only upper triangular portion exists, row-major)
 
     int i, rv = 0;
 
