@@ -1,5 +1,5 @@
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,6 +10,8 @@
 
 #pragma once
 
+#include <util/api.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -17,9 +19,9 @@ extern "C" {
 #include <neatogen/defs.h>
 #include <neatogen/sgd.h>
 
-    extern void ngdijkstra(int, vtx_data *, int, DistType *);
-    extern void dijkstra_f(int, vtx_data *, int, float *);
-    extern int dijkstra_sgd(graph_sgd *, int, term_sgd *);
+PRIVATE void ngdijkstra(int, vtx_data *, int, DistType *);
+PRIVATE void dijkstra_f(int, vtx_data *, int, float *);
+PRIVATE int dijkstra_sgd(graph_sgd *, int, term_sgd *);
 
 #ifdef __cplusplus
 }
