@@ -8,6 +8,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include <assert.h>
 #include "config.h"
 #include <limits.h>
@@ -651,6 +653,20 @@ static int spline_edges_(graph_t *g, expand_t *pmargin, int edgetype) {
 	    node_t *head = aghead(e);
 	    if (useEdges && ED_spl(e)) {
 		addEdgeLabels(e);
+		if (Nop == 3 && ED_spl(e)->size > 0) {
+		    // use first bezier, start point and end point will lost
+		    if (ED_spl(e)->size > 1) {
+			agwarningf("edge %s -> %s : set more than one spline. First used, other dropped.\n", agnameof(n), agnameof(head));
+		    }
+		    bezier *bez = ED_spl(e)->list;
+		    size_t sz = bez->size;
+		    bez->size = 0;
+		    pointf *pb = bez->list;
+		    bez->list = NULL;
+		    gv_free_splines(e);
+		    clip_and_install(e, head, pb, sz, &sinfo);
+		    free(pb);
+		}
 	    } 
 	    else if (ED_count(e) == 0) continue;  /* only do representative */
 	    else if (n == head) {    /* self arc */
