@@ -3,12 +3,13 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/alloc.h>
+#include "config.h"
+
 #include <neatogen/matrix_ops.h>
 #include <neatogen/pca.h>
 #include <neatogen/closest.h>
@@ -16,6 +17,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#include <util/alloc.h>
 
 static int num_pairs = 4;
 
@@ -29,7 +31,6 @@ PCA_alloc(DistType ** coords, int dim, int n, double **new_coords,
     double **eigs = gv_calloc(new_dim, sizeof(double *));
     for (i = 0; i < new_dim; i++)
 	eigs[i] = gv_calloc(dim, sizeof(double));
-    double *evals = gv_calloc(new_dim, sizeof(double));
 
     double **DD = gv_calloc(dim, sizeof(double *)); // dim×dim matrix: coords×coordsᵀ
     double *storage_ptr = gv_calloc(dim * dim, sizeof(double));
@@ -49,7 +50,7 @@ PCA_alloc(DistType ** coords, int dim, int n, double **new_coords,
 	}
     }
 
-    power_iteration(DD, dim, new_dim, eigs, evals);
+    power_iteration(DD, dim, new_dim, eigs);
 
     for (j = 0; j < new_dim; j++) {
 	for (i = 0; i < n; i++) {
@@ -64,7 +65,6 @@ PCA_alloc(DistType ** coords, int dim, int n, double **new_coords,
     for (i = 0; i < new_dim; i++)
 	free(eigs[i]);
     free(eigs);
-    free(evals);
     free(DD[0]);
     free(DD);
 }
@@ -73,7 +73,6 @@ bool iterativePCA_1D(double **coords, int dim, int n, double *new_direction) {
     vtx_data *laplacian;
     float **mat1 = NULL;
     double **mat = NULL;
-    double eval;
 
     /* Given that first projection of 'coords' is 'coords[0]'
        compute another projection direction 'new_direction'
@@ -91,6 +90,8 @@ bool iterativePCA_1D(double **coords, int dim, int n, double *new_direction) {
     free(mat1);
 
     /* Compute direction */
-    return power_iteration(mat, dim, 1, &new_direction, &eval);
-/* ?? When is mat freed? */
+    const bool result = power_iteration(mat, dim, 1, &new_direction);
+    free(mat[0]);
+    free(mat);
+    return result;
 }
