@@ -10,18 +10,15 @@
 
 #pragma once
 
+#include <stdbool.h>
+#include <util/api.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 #include <neatogen/geometry.h>
 
-#if !defined(__CYGWIN__) && defined(__GNUC__) && !defined(__MINGW32__)
-#define INTERNAL __attribute__((visibility("hidden")))
-#else
-#define INTERNAL /* nothing */
-#endif
-
     typedef struct {
 	Point origin;
 	Point corner;
@@ -30,13 +27,10 @@ extern "C" {
 	int kind;
     } Poly;
 
-INTERNAL void polyFree(void);
-INTERNAL int polyOverlap(Point, Poly *, Point, Poly *);
-INTERNAL int makePoly(Poly *, Agnode_t *, double, double);
-INTERNAL int makeAddPoly(Poly *, Agnode_t *, double, double);
-INTERNAL void breakPoly(Poly *);
-
-#undef INTERNAL
+PRIVATE bool polyOverlap(Point, Poly *, Point, Poly *);
+PRIVATE int makePoly(Poly *, Agnode_t *, double, double);
+PRIVATE int makeAddPoly(Poly *, Agnode_t *, double, double);
+PRIVATE void breakPoly(Poly *);
 
 #ifdef __cplusplus
 }
