@@ -17,21 +17,12 @@
 #include	<stdlib.h>
 #include	<time.h>
 #include	<util/alloc.h>
-#ifndef _WIN32
-#include	<unistd.h>
-#endif
 
 static double Epsilon2;
 static Agnode_t *choose_node(graph_t *, int);
 static void make_spring(graph_t *, Agnode_t *, Agnode_t *, double);
 static void move_node(graph_t *, int, Agnode_t *);
 
-static double fpow32(double x)
-{
-    x = sqrt(x);
-    return x * x * x;
-}
-
 static double distvec(double *p0, double *p1, double *vec)
 {
     int k;
@@ -101,9 +92,7 @@ static void free_3array(double ***rv)
     }
 }
 
-
-/* lenattr:
- * Return 1 if attribute not defined
+/* Return 1 if attribute not defined
  * Return 2 if attribute string bad
  */
 static int lenattr(edge_t* e, Agsym_t* index, double* val)
@@ -124,9 +113,7 @@ static int lenattr(edge_t* e, Agsym_t* index, double* val)
 	return 0;
 }
 
-
-/* degreeKind;
- * Returns degree of n ignoring loops and multiedges.
+/* Returns degree of n ignoring loops and multiedges.
  * Returns 0, 1 or many (2)
  * For case of 1, returns other endpoint of edge.
  */
@@ -156,9 +143,7 @@ static int degreeKind(graph_t * g, node_t * n, node_t ** op)
     return deg;
 }
 
-
-/* prune:
- * np is at end of a chain. If its degree is 0, remove it.
+/* np is at end of a chain. If its degree is 0, remove it.
  * If its degree is 1, remove it and recurse.
  * If its degree > 1, stop.
  * The node next is the next node to be visited during iteration.
@@ -208,8 +193,7 @@ static double setEdgeLen(graph_t * G, node_t * np, Agsym_t* lenx, double dfltlen
     return total_len;
 }
 
-/* scan_graph_mode:
- * Prepare the graph and data structures depending on the layout mode.
+/* Prepare the graph and data structures depending on the layout mode.
  * If Reduce is true, eliminate singletons and trees. Since G may be a
  * subgraph, we remove the nodes from the root graph.
  * Return the number of nodes in the reduced graph.
@@ -263,7 +247,7 @@ int scan_graph_mode(graph_t * G, int mode)
     } else if (mode == MODE_SGD) {
 	Epsilon = .01;
 	getdouble(G, "epsilon", &Epsilon);
-	GD_neato_nlist(G) = gv_calloc(nV + 1, sizeof(node_t*)); // not sure why but sometimes needs the + 1
+	GD_neato_nlist(G) = gv_calloc(nV + 1, sizeof(node_t *));
 	for (i = 0, np = agfstnode(G); np; np = agnxtnode(G, np)) {
 	    GD_neato_nlist(G)[i] = np;
 	    ND_id(np) = i++;
@@ -372,7 +356,7 @@ void diffeq_model(graph_t * G, int nG)
 	for (j = 0; j < i; j++) {
 	    f = Spring_coeff / (D[i][j] * D[i][j]);
 	    if ((e = agfindedge(G, GD_neato_nlist(G)[i], GD_neato_nlist(G)[j])))
-		f = f * ED_factor(e);
+		f *= ED_factor(e);
 	    K[i][j] = K[j][i] = f;
 	}
     }
@@ -402,9 +386,7 @@ void diffeq_model(graph_t * G, int nG)
     }
 }
 
-/* total_e:
- * Return 2*energy of system.
- */
+/// return 2 × energy of system
 static double total_e(graph_t * G, int nG)
 {
     int i, j, d;
@@ -452,7 +434,7 @@ void solve_model(graph_t * G, int nG)
 static void update_arrays(graph_t * G, int nG, int i)
 {
     int j, k;
-    double del[MAXDIM], dist, old;
+    double del[MAXDIM], dist;
     node_t *vi, *vj;
 
     vi = GD_neato_nlist(G)[i];
@@ -464,12 +446,11 @@ static void update_arrays(graph_t * G, int nG, int i)
 	vj = GD_neato_nlist(G)[j];
 	dist = distvec(ND_pos(vi), ND_pos(vj), del);
 	for (k = 0; k < Ndim; k++) {
-	    old = GD_t(G)[i][j][k];
 	    GD_t(G)[i][j][k] =
 		GD_spring(G)[i][j] * (del[k] -
 				      GD_dist(G)[i][j] * del[k] / dist);
 	    GD_sum_t(G)[i][k] += GD_t(G)[i][j][k];
-	    old = GD_t(G)[j][i][k];
+	    const double old = GD_t(G)[j][i][k];
 	    GD_t(G)[j][i][k] = -GD_t(G)[i][j][k];
 	    GD_sum_t(G)[j][k] += GD_t(G)[j][i][k] - old;
 	}
@@ -496,9 +477,9 @@ static void D2E(graph_t * G, int nG, int n, double *M)
 	sq = 0.0;
 	for (k = 0; k < Ndim; k++) {
 	    t[k] = ND_pos(vn)[k] - ND_pos(vi)[k];
-	    sq += (t[k] * t[k]);
+	    sq += t[k] * t[k];
 	}
-	scale = 1 / fpow32(sq);
+	scale = 1 / pow(sq, 1.5);
 	for (k = 0; k < Ndim; k++) {
 	    for (l = 0; l < k; l++)
 		Msub(l, k) += K[n][i] * D[n][i] * t[k] * t[l] * scale;
@@ -605,8 +586,7 @@ static void heapdown(node_t * v)
     i = ND_heapindex(v);
     while ((left = 2 * i + 1) < Heapsize) {
 	right = left + 1;
-	if ((right < Heapsize)
-	    && (ND_dist(Heap[right]) < ND_dist(Heap[left])))
+	if (right < Heapsize && ND_dist(Heap[right]) < ND_dist(Heap[left]))
 	    c = right;
 	else
 	    c = left;
