@@ -3,15 +3,19 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
 
 #include <math.h>
 #include <pathplan/solvers.h>
 
+static int solve1(double *coeff, double *roots);
+static int solve2(double *coeff, double *roots);
+
 #ifndef M_PI
 #define M_PI 3.14159265358979323846
 #endif
@@ -62,7 +66,7 @@ int solve3(double *coeff, double *roots)
     return rootn;
 }
 
-int solve2(double *coeff, double *roots)
+static int solve2(double *coeff, double *roots)
 {
     double a, b, c;
     double disc, b_over_2a, c_over_a;
@@ -74,19 +78,18 @@ int solve2(double *coeff, double *roots)
     c_over_a = c / a;
 
     disc = b_over_2a * b_over_2a - c_over_a;
-    if (disc < 0)
+    if (disc < 0) {
 	return 0;
-    else if (disc == 0) {
-	roots[0] = -b_over_2a;
-	return 1;
-    } else {
+    } else if (disc > 0) {
 	roots[0] = -b_over_2a + sqrt(disc);
 	roots[1] = -2 * b_over_2a - roots[0];
 	return 2;
     }
+    roots[0] = -b_over_2a;
+    return 1;
 }
 
-int solve1(double *coeff, double *roots)
+static int solve1(double *coeff, double *roots)
 {
     double a, b;
 
