@@ -3,16 +3,13 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
 #include	<sfio/sfhdr.h>
 
-#undef sfslen
-
-ssize_t sfslen(void)
-{
-    return __sf_slen();
-}
+ssize_t sfslen(void) { return _Sfi; }
