@@ -3,13 +3,15 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #pragma once
 
+#include <stdbool.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -21,10 +23,9 @@ struct Multilevel_MQ_Clustering_struct {
   int n;
   SparseMatrix A; /* n x n matrix */
   SparseMatrix P; 
-  SparseMatrix R; 
   Multilevel_MQ_Clustering next;
   Multilevel_MQ_Clustering prev;
-  int delete_top_level_A;
+  bool delete_top_level_A;
   int *matching; /* dimension n. matching[i] is the clustering assignment of node i */
 
   /*
@@ -46,19 +47,17 @@ struct Multilevel_MQ_Clustering_struct {
 
 /* find a clustering of vertices by maximize modularity quality
    A: symmetric square matrix n x n. If real value, value will be used as edges weights, otherwise edge weights are considered as 1.
-   inplace: whether A can e modified. If true, A will be modified by removing diagonal.
 
    maxcluster: used to specify the maximum number of cluster desired, e.g., maxcluster=10 means that a maximum of 10 clusters
    .   is desired. this may not always be realized, and modularity quality may be low when this is specified. Default: maxcluster = 0 (no limit)
 
-   use_value: whether to use the entry value, or treat edge weights as 1.
    nclusters: on output the number of clusters
    assignment: dimension n. Node i is assigned to cluster "assignment[i]". 0 <= assignment < nclusters.
    .   If *assignment = NULL on entry, it will be allocated. Otherwise used.
    mq: achieve modularity
 */
-void mq_clustering(SparseMatrix A, int inplace, int maxcluster, int use_value,
-			   int *nclusters, int **assignment, double *mq, int *flag);
+void mq_clustering(SparseMatrix A, int maxcluster,
+			   int *nclusters, int **assignment, double *mq);
 
 #ifdef __cplusplus
 }
