@@ -3,17 +3,13 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
 
-#ifdef _WIN32
-#include <io.h>
-#endif
-
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -26,21 +22,21 @@
 
 #include <gvc/gvplugin_render.h>
 #include <gvc/gvplugin_device.h>
-#include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
-#include <cgraph/startswith.h>
-#include <cgraph/unreachable.h>
 #include <common/utils.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
 #include <gvc/gvcint.h>
+#include <util/alloc.h>
+#include <util/startswith.h>
+#include <util/streq.h>
+#include <util/unreachable.h>
 
-typedef enum {
+enum {
 	FORMAT_JSON,
 	FORMAT_JSON0,
 	FORMAT_DOT_JSON,
 	FORMAT_XDOT_JSON,
-} format_type;
+};
 
 typedef struct {
     int Level;
@@ -54,9 +50,9 @@ typedef struct {
 } gvid_t;
 
 #define ID "id"
-#define ND_gid(n) (((gvid_t*)aggetrec(n, ID, FALSE))->id) 
-#define ED_gid(n) (((gvid_t*)aggetrec(n, ID, FALSE))->id) 
-#define GD_gid(n) (((gvid_t*)aggetrec(n, ID, FALSE))->id) 
+#define ND_gid(n) (((gvid_t*)aggetrec(n, ID, 0))->id) 
+#define ED_gid(n) (((gvid_t*)aggetrec(n, ID, 0))->id) 
+#define GD_gid(n) (((gvid_t*)aggetrec(n, ID, 0))->id) 
 
 static bool IS_CLUSTER(Agraph_t *s) {
   return startswith(agnameof(s), "cluster");
@@ -75,16 +71,16 @@ static void json_begin_graph(GVJ_t *job)
     }
 }
 
-#define LOCALNAMEPREFIX		'%'
-
-/* stoj:
- * Convert dot string to a valid json string embedded in double quotes.
+/** Convert dot string to a valid json string embedded in double quotes and
+ *   output
+ *
+ * \param ins Input string
+ * \param sp State, used to determine encoding of the input string
+ * \param job Output job
  */
-static char* stoj (char* ins, state_t* sp)
-{
+static void stoj(char *ins, state_t *sp, GVJ_t *job) {
     char* s;
     char* input;
-    static agxbuf xb;
     char c;
 
     if (sp->isLatin)
@@ -92,44 +88,42 @@ static char* stoj (char* ins, state_t* sp)
     else
 	input = ins;
 
-    if (xb.buf == NULL)
-	agxbinit(&xb, BUFSIZ, NULL);
+    gvputc(job, '"');
     for (s = input; (c = *s); s++) {
 	switch (c) {
 	case '"' :
-	    agxbput(&xb, "\\\"");
+	    gvputs(job, "\\\"");
 	    break;
 	case '\\' :
-	    agxbput(&xb, "\\\\");
+	    gvputs(job, "\\\\");
 	    break;
 	case '/' :
-	    agxbput(&xb, "\\/");
+	    gvputs(job, "\\/");
 	    break;
 	case '\b' :
-	    agxbput(&xb, "\\b");
+	    gvputs(job, "\\b");
 	    break;
 	case '\f' :
-	    agxbput(&xb, "\\f");
+	    gvputs(job, "\\f");
 	    break;
 	case '\n' :
-	    agxbput(&xb, "\\n");
+	    gvputs(job, "\\n");
 	    break;
 	case '\r' :
-	    agxbput(&xb, "\\r");
+	    gvputs(job, "\\r");
 	    break;
 	case '\t' :
-	    agxbput(&xb, "\\t");
+	    gvputs(job, "\\t");
 	    break;
 	default :
-	    agxbputc(&xb, c);
+	    gvputc(job, c);
 	    break;
 	}
     }
-    s = agxbuse(&xb);
+    gvputc(job, '"');
 
     if (sp->isLatin)
 	free (input);
-    return s;
 }
 
 static void indent(GVJ_t * job, int level)
@@ -178,8 +172,9 @@ static void write_stops (GVJ_t * job, int n_stops, xdot_color_stop* stp, state_t
     gvprintf(job, "\"stops\": [");
     for (i = 0; i < n_stops; i++) {
 	if (i > 0) gvprintf(job, ",");
-	gvprintf(job, "{\"frac\": %.03f, \"color\": \"%s\"}",
-	    stp[i].frac, stoj(stp[i].color, sp));
+	gvprintf(job, "{\"frac\": %.03f, \"color\": ", stp[i].frac);
+	stoj(stp[i].color, sp, job);
+	gvputc(job, '}');
     }
     gvprintf(job, "]\n");
 } 
@@ -246,7 +241,9 @@ static void write_xdot (xdot_op * op, GVJ_t * job, state_t* sp)
  	indent(job, sp->Level);
 	gvprintf(job, "\"width\": %.03f,\n", op->u.text.width); 
  	indent(job, sp->Level);
-	gvprintf(job, "\"text\": \"%s\"\n", stoj(op->u.text.text, sp));
+	gvputs(job, "\"text\": ");
+	stoj(op->u.text.text, sp, job);
+	gvputc(job, '\n');
 	break;
     case xd_fill_color :
     case xd_pen_color :
@@ -254,7 +251,9 @@ static void write_xdot (xdot_op * op, GVJ_t * job, state_t* sp)
  	indent(job, sp->Level);
 	gvprintf(job, "\"grad\": \"none\",\n"); 
  	indent(job, sp->Level);
-	gvprintf(job, "\"color\": \"%s\"\n", stoj(op->u.color, sp));
+	gvputs(job, "\"color\": ");
+	stoj(op->u.color, sp, job);
+	gvputc(job, '\n');
 	break;
     case xd_grad_pen_color :
     case xd_grad_fill_color :
@@ -263,8 +262,9 @@ static void write_xdot (xdot_op * op, GVJ_t * job, state_t* sp)
 	if (op->u.grad_color.type == xd_none) {
 	    gvprintf(job, "\"grad\": \"none\",\n"); 
  	    indent(job, sp->Level);
-	    gvprintf(job, "\"color\": \"%s\"\n", 
-		stoj(op->u.grad_color.u.clr, sp));
+	    gvputs(job, "\"color\": ");
+	    stoj(op->u.grad_color.u.clr, sp, job);
+	    gvputc(job, '\n');
 	}
 	else {
 	    if (op->u.grad_color.type == xd_linear) {
@@ -284,12 +284,16 @@ static void write_xdot (xdot_op * op, GVJ_t * job, state_t* sp)
  	indent(job, sp->Level);
 	gvprintf(job, "\"size\": %.03f,\n", op->u.font.size); 
  	indent(job, sp->Level);
-	gvprintf(job, "\"face\": \"%s\"\n", stoj(op->u.font.name, sp)); 
+	gvputs(job, "\"face\": ");
+	stoj(op->u.font.name, sp, job);
+	gvputc(job, '\n');
 	break;
     case xd_style :
 	gvprintf(job, "\"op\": \"S\",\n");
  	indent(job, sp->Level);
-	gvprintf(job, "\"style\": \"%s\"\n", stoj(op->u.style, sp));
+	gvputs(job, "\"style\": ");
+	stoj(op->u.style, sp, job);
+	gvputc(job, '\n');
 	break;
     case xd_image :
 	break;
@@ -314,7 +318,7 @@ static void write_xdots (char * val, GVJ_t * job, state_t* sp)
 
     cmds = parseXDot(val);
     if (!cmds) {
-	agerr(AGWARN, "Could not parse xdot \"%s\"\n", val);
+	agwarningf("Could not parse xdot \"%s\"\n", val);
 	return;
     }
 
@@ -352,11 +356,12 @@ static void write_attrs(Agobj_t * obj, GVJ_t * job, state_t* sp)
 	if (*attrval == '\0' && !streq(sym->name, "label")) continue;
 	gvputs(job, ",\n");
 	indent(job, sp->Level);
-	gvprintf(job, "\"%s\": ", stoj(sym->name, sp));
+	stoj(sym->name, sp, job);
+	gvputs(job, ": ");
 	if (sp->doXDot && isXDot(sym->name))
 	    write_xdots(agxget(obj, sym), job, sp);
 	else
-	    gvprintf(job, "\"%s\"", stoj(agxget(obj, sym), sp));
+	    stoj(agxget(obj, sym), sp, job);
     }
 }
 
@@ -365,7 +370,8 @@ static void write_hdr(Agraph_t *g, GVJ_t *job, bool top, state_t *sp) {
 
     name = agnameof(g);
     indent(job, sp->Level);
-    gvprintf(job, "\"name\": \"%s\"", stoj (name, sp));
+    gvputs(job, "\"name\": ");
+    stoj(name, sp, job);
 
     if (top) {
 	gvputs(job, ",\n");
@@ -425,8 +431,19 @@ static bool write_subgs(Agraph_t *g, GVJ_t *job, bool top, state_t *sp) {
     return true;
 }
 
-static int agseqasc(Agedge_t **lhs, Agedge_t **rhs)
-{
+static int agseqasc(const void *x, const void *y) {
+// Suppress Clang/GCC -Wcast-qual warning. Casting away const here is acceptable
+// as the later usage is const. We need the cast because the macros use
+// non-const pointers for genericity.
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-qual"
+#endif
+  Agedge_t **lhs = (Agedge_t **)x;
+  Agedge_t **rhs = (Agedge_t **)y;
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
     Agedge_t *e1 = *lhs;
     Agedge_t *e2 = *rhs;
 
@@ -451,7 +468,7 @@ static void write_edge(Agedge_t *e, GVJ_t *job, bool top, state_t *sp) {
 	gvprintf(job, "\"tail\": %d,\n", ND_gid(agtail(e)));
 	indent(job, sp->Level);
 	gvprintf(job, "\"head\": %d", ND_gid(aghead(e)));
-    	write_attrs((Agobj_t*)e, job, sp);
+    	write_attrs(&e->base, job, sp);
 	gvputs(job, "\n");
 	sp->Level--;
 	indent(job, sp->Level);
@@ -485,7 +502,7 @@ static int write_edges(Agraph_t *g, GVJ_t *job, bool top, state_t *sp) {
         }
     }
 
-    qsort(edges, count, sizeof(Agedge_t *), (qsort_cmpf)agseqasc);
+    qsort(edges, count, sizeof(Agedge_t *), agseqasc);
 
     gvputs(job, ",\n");
     indent(job, sp->Level++);
@@ -518,8 +535,9 @@ static void write_node(Agnode_t *n, GVJ_t *job, bool top, state_t *sp) {
 	indent(job, sp->Level);
 	gvprintf(job, "\"_gvid\": %d,\n", ND_gid(n));
 	indent(job, sp->Level);
-	gvprintf(job, "\"name\": \"%s\"", stoj (agnameof(n), sp));
-    	write_attrs((Agobj_t*)n, job, sp);
+	gvputs(job, "\"name\": ");
+	stoj(agnameof(n), sp, job);
+    	write_attrs(&n->base, job, sp);
 	gvputs(job, "\n");
 	sp->Level--;
 	indent(job, sp->Level);
@@ -582,10 +600,8 @@ typedef struct {
     int v;
 } intm;
 
-static void freef(Dt_t * dt, intm * obj, Dtdisc_t * disc)
-{
-    (void)dt;
-    (void)disc;
+static void freef(void *ident) {
+    intm *obj = ident;
     free(obj->id);
     free(obj);
 }
@@ -594,12 +610,9 @@ static Dtdisc_t intDisc = {
     offsetof(intm, id),
     -1,
     offsetof(intm, link),
-    (Dtmake_f) NULL,
-    (Dtfree_f) freef,
-    (Dtcompar_f) NULL,
-    0,
-    0,
-    0
+    NULL,
+    freef,
+    NULL,
 };
 
 static int lookup (Dt_t* map, char* name)
@@ -615,11 +628,11 @@ static void insert (Dt_t* map, char* name, int v)
 
     if (ip) {
 	if (ip->v != v)
-	    agerr(AGWARN, "Duplicate cluster name \"%s\"\n", name);
+	    agwarningf("Duplicate cluster name \"%s\"\n", name);
 	return;
     }
     ip = gv_alloc(sizeof(intm));
-    ip->id = strdup(name);
+    ip->id = gv_strdup(name);
     ip->v = v;
     dtinsert (map, ip);
 }
@@ -650,9 +663,9 @@ static void write_graph(Agraph_t *g, GVJ_t *job, bool top, state_t *sp) {
 
     if (top) {
 	map = dtopen (&intDisc, Dtoset);
-	aginit(g, AGNODE, ID, sizeof(gvid_t), FALSE);
-	aginit(g, AGEDGE, ID, sizeof(gvid_t), FALSE);
-	aginit(g, AGRAPH, ID, -((int)sizeof(gvid_t)), FALSE);
+	aginit(g, AGNODE, ID, sizeof(gvid_t), false);
+	aginit(g, AGEDGE, ID, sizeof(gvid_t), false);
+	aginit(g, AGRAPH, ID, -((int)sizeof(gvid_t)), false);
 	sgcnt = label_subgs(g, sgcnt, map);
 	for (np = agfstnode(g); np; np = agnxtnode(g,np)) {
 	    if (IS_CLUST_NODE(np)) {
@@ -671,7 +684,7 @@ static void write_graph(Agraph_t *g, GVJ_t *job, bool top, state_t *sp) {
     indent(job, sp->Level++);
     gvputs(job, "{\n");
     write_hdr(g, job, top, sp);
-    write_attrs((Agobj_t*)g, job, sp);
+    write_attrs(&g->base, job, sp);
     if (top) {
 	gvputs(job, ",\n");
 	indent(job, sp->Level);
@@ -717,7 +730,7 @@ static void json_end_graph(GVJ_t *job)
     write_graph(g, job, true, &sp);
 }
 
-gvrender_engine_t json_engine = {
+static gvrender_engine_t json_engine = {
     0,				/* json_begin_job */
     0,				/* json_end_job */
     json_begin_graph,
@@ -750,15 +763,7 @@ gvrender_engine_t json_engine = {
     0,				/* json_library_shape */
 };
 
-gvrender_features_t render_features_json1 = {
-    GVRENDER_DOES_TRANSFORM,	/* not really - uses raw graph coords */  /* flags */
-    0.,                         /* default pad - graph units */
-    NULL,			/* knowncolors */
-    0,				/* sizeof knowncolors */
-    COLOR_STRING,		/* color_type */
-};
-
-gvrender_features_t render_features_json = {
+static gvrender_features_t render_features_json = {
     GVRENDER_DOES_TRANSFORM	/* not really - uses raw graph coords */
 	| GVRENDER_DOES_MAPS
 	| GVRENDER_DOES_TARGETS
@@ -769,14 +774,14 @@ gvrender_features_t render_features_json = {
     COLOR_STRING,		/* color_type */
 };
 
-gvdevice_features_t device_features_json_nop = {
+static gvdevice_features_t device_features_json_nop = {
     LAYOUT_NOT_REQUIRED,	/* flags */
     {0.,0.},			/* default margin - points */
     {0.,0.},			/* default page width, height - points */
     {72.,72.},			/* default dpi */
 };
 
-gvdevice_features_t device_features_json = {
+static gvdevice_features_t device_features_json = {
     0,				/* flags */
     {0.,0.},			/* default margin - points */
     {0.,0.},			/* default page width, height - points */
