@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -13,25 +13,39 @@
 #include <stdlib.h>
 #include <stddef.h>
 #include <string.h>
+#include <util/gv_math.h>
 
 #include <gvc/gvplugin_loadimage.h>
 #include "gvplugin_gdiplus.h"
-
+#include <stringapiset.h>
 #include <windows.h>
-#include "GdiPlus.h"
-
-#include "FileStream.h"
+#include <gdiplus.h>
+#include <vector>
 
 using namespace Gdiplus;
 
-static void gdiplus_freeimage(usershape_t *us)
-{
-	delete (Image*)us->data;
+static void gdiplus_freeimage(usershape_t *us) {
+  delete reinterpret_cast<Image*>(us->data);
 }
 
-static Image* gdiplus_loadimage(GVJ_t * job, usershape_t *us)
-{
-    assert(job);
+// convert a UTF-8 string to UTF-16
+static std::vector<wchar_t> utf8_to_utf16(const char *s) {
+
+  // how much space do we need for the UTF-16 string?
+  const int wide_count = MultiByteToWideChar(CP_UTF8, 0, s, -1, nullptr, 0);
+
+  // translate it
+  std::vector<wchar_t> utf16(wide_count);
+  if (wide_count > 0) {
+    (void)MultiByteToWideChar(CP_UTF8, 0, s, -1, utf16.data(), wide_count);
+  } else {
+    utf16.push_back(0);
+  }
+
+  return utf16;
+}
+
+static Image *gdiplus_loadimage(usershape_t *us) {
     assert(us);
     assert(us->name);
 
@@ -46,27 +60,26 @@ static Image* gdiplus_loadimage(GVJ_t * job, usershape_t *us)
 			return nullptr;
 
 		/* create image from the usershape file */
-		/* NOTE: since Image::FromStream consumes the stream, we assume FileStream's lifetime should be shorter than us->name and us->f... */	
-		IStream *stream = FileStream::Create(const_cast<char*>(us->name), us->f);
-		us->data = Image::FromStream (stream);
+		const std::vector<wchar_t> filename = utf8_to_utf16(us->name);
+		us->data = Image::FromFile(filename.data());
 		
 		/* clean up */
 		if (us->data)
 			us->datafree = gdiplus_freeimage;
-		stream->Release();
 			
 		gvusershape_file_release(us);
     }
     return reinterpret_cast<Image*>(us->data);
 }
 
-static void gdiplus_loadimage_gdiplus(GVJ_t * job, usershape_t *us, boxf b, boolean filled)
+static void gdiplus_loadimage_gdiplus(GVJ_t * job, usershape_t *us, boxf b, bool)
 {
 	/* get the image from usershape details, then blit it to the context */
-	Image *image = gdiplus_loadimage(job, us);
-	if (image) {
+	if (Image *image = gdiplus_loadimage(us)) {
+		assert(job != NULL);
 		auto g = reinterpret_cast<Graphics*>(job->context);
-		g->DrawImage(image, RectF(b.LL.x, b.LL.y, b.UR.x - b.LL.x, b.UR.y - b.LL.y));
+		g->DrawImage(image, RectF(d2f(b.LL.x), d2f(b.LL.y), d2f(b.UR.x - b.LL.x),
+		                          d2f(b.UR.y - b.LL.y)));
 	}
 }
 
