@@ -1,13 +1,16 @@
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include "config.h"
+
+#include <guiddef.h>
 #include <gvc/gvplugin.h>
 
 #include "gvplugin_gdiplus.h"
@@ -71,7 +74,7 @@ void SaveBitmapToStream(Bitmap &bitmap, IStream *stream, int format)
 	ImageCodecInfo *codecs = (ImageCodecInfo *)&codec_buffer.front();
 	GetImageEncoders(encoderNum, encoderSize, codecs);
 	for (UINT i = 0; i < encoderNum; ++i)
-		if (memcmp(&(format_id[format]), &codecs[i].FormatID, sizeof(GUID)) == 0) {
+		if (IsEqualGUID(format_id[format], codecs[i].FormatID)) {
 			bitmap.Save(stream, &codecs[i].Clsid, nullptr);
 			break;
 		}
@@ -90,13 +93,15 @@ static gvplugin_api_t apis[] = {
 extern "C" {
 #endif
 
-#ifdef _WIN32
-#   define GVPLUGIN_GDIPLUS_API __declspec(dllexport)
+#ifdef GVDLL
+#define GVPLUGIN_GDIPLUS_API __declspec(dllexport)
 #else
-#   define GVPLUGIN_GDIPLUS_API
+#define GVPLUGIN_GDIPLUS_API
 #endif
 
-GVPLUGIN_GDIPLUS_API gvplugin_library_t gvplugin_gdiplus_LTX_library = { "gdiplus", apis };
+GVPLUGIN_GDIPLUS_API gvplugin_library_t gvplugin_gdiplus_LTX_library = {
+  const_cast<char*>("gdiplus"), apis
+};
 
 #ifdef __cplusplus
 }
