@@ -14,7 +14,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <TargetConditionals.h>
 
 #include <gvc/gvplugin_loadimage.h>
 
@@ -30,6 +29,8 @@ static void file_data_provider_rewind(void *info)
   rewind(info);
 }
 
+#if __MAC_OS_X_VERSION_MIN_REQUIRED >= 1050 || __IPHONE_OS_VERSION_MIN_REQUIRED >= 20000
+
 static off_t file_data_provider_skip_forward(void *info, off_t count)
 {
 	fseek((FILE*)info, count, SEEK_CUR);
@@ -45,6 +46,25 @@ static CGDataProviderSequentialCallbacks file_data_provider_callbacks = {
 	NULL
 };
 
+#else
+
+static void file_data_provider_skip_bytes(void *info, size_t count)
+{
+	fseek((FILE*)info, count, SEEK_CUR);
+}
+
+/* bridge FILE* to a sequential CGDataProvider */
+static CGDataProviderCallbacks file_data_provider_callbacks = {
+	file_data_provider_get_bytes,
+	file_data_provider_skip_bytes,
+	file_data_provider_rewind,
+	NULL
+};
+
+#endif
+
+
+
 static void quartz_freeimage(usershape_t *us)
 {
 	CGImageRelease(us->data);
@@ -66,9 +86,13 @@ static CGImageRef quartz_loadimage(GVJ_t * job, usershape_t *us)
 		if (!gvusershape_file_access(us))
 			return NULL;
 			
+#if __MAC_OS_X_VERSION_MIN_REQUIRED >= 1050 || __IPHONE_OS_VERSION_MIN_REQUIRED >= 20000
 		CGDataProviderRef data_provider = CGDataProviderCreateSequential(us->f, &file_data_provider_callbacks);
+#else
+		CGDataProviderRef data_provider = CGDataProviderCreate(us->f, &file_data_provider_callbacks);	
+#endif
 		
-#if !TARGET_OS_IPHONE
+#if __MAC_OS_X_VERSION_MIN_REQUIRED >= 1040
 		/* match usershape format to a UTI for type hinting, if possible */
 		format_type hint_format_type;
 		switch (us->type) {
@@ -148,7 +172,7 @@ static gvloadimage_engine_t engine = {
 };
 
 gvplugin_installed_t gvloadimage_quartz_types[] = {
-#if !TARGET_OS_IPHONE
+#if __MAC_OS_X_VERSION_MIN_REQUIRED >= 1040
 	{FORMAT_BMP, "bmp:quartz", 8, &engine, NULL},
 	{FORMAT_GIF, "gif:quartz", 8, &engine, NULL},
 	{FORMAT_PDF, "pdf:quartz", 8, &engine, NULL},
