@@ -10,39 +10,33 @@
 
 #include "config.h"
 
+#include <assert.h>
+#include <common/render.h>
+#include <common/utils.h>
 #include <stdbool.h>
-#include <stdlib.h>
-#include <sys/stat.h>
+#include <stddef.h>
 
 #include <gvc/gvplugin_loadimage.h>
 
-#ifdef HAVE_PANGOCAIRO
-#ifdef HAVE_RSVG
 #include <librsvg/rsvg.h>
 #ifndef RSVG_CAIRO_H
 #include <librsvg/rsvg-cairo.h>
 #endif
 #include <cairo-svg.h>
 
-typedef enum {
+enum {
     FORMAT_SVG_CAIRO,
-} format_type;
-
+};
 
 static void gvloadimage_rsvg_free(usershape_t *us)
 {
-    rsvg_handle_close(us->data, NULL);
+  g_object_unref(us->data);
 }
 
 static RsvgHandle* gvloadimage_rsvg_load(GVJ_t * job, usershape_t *us)
 {
     RsvgHandle* rsvgh = NULL;
-    unsigned char *fileBuf = NULL;
     GError *err = NULL;
-    size_t fileSize;
-
-    int fd;
-    struct stat stbuf;
 
     assert(job);
     assert(us);
@@ -62,46 +56,22 @@ static RsvgHandle* gvloadimage_rsvg_load(GVJ_t * job, usershape_t *us)
 	if (!gvusershape_file_access(us))
 	    return NULL;
         switch (us->type) {
-            case FT_SVG:
-      		rsvgh = rsvg_handle_new();
+            case FT_SVG: {
+      		const char *const safe_path = safefile(us->name);
+      		assert(safe_path != NULL &&
+      		       "gvusershape_file_access did not validate file path");
+      		rsvgh = rsvg_handle_new_from_file(safe_path, &err);
 		
 		if (rsvgh == NULL) {
 			fprintf(stderr, "rsvg_handle_new_from_file returned an error: %s\n", err->message);
+			g_error_free(err);
 			return NULL;
 		} 
 
-	 	fd = fileno(us->f);
-		fstat(fd, &stbuf);
-  		fileSize = (size_t)stbuf.st_size;	
-
-		fileBuf = calloc(fileSize + 1, sizeof(unsigned char));
-
-		if (fileBuf == NULL) {
-			g_object_unref(rsvgh);
-			return NULL;
-		}
-	
-		rewind(us->f);
-
-		if (fread(fileBuf, 1, fileSize, us->f) < fileSize) {
-			free(fileBuf);
-			g_object_unref(rsvgh);
-			return NULL;
-		}
-
-		if (!rsvg_handle_write(rsvgh, fileBuf, (gsize)fileSize, &err)) {
-			fprintf(stderr, "rsvg_handle_write returned an error: %s\n", err->message);
-			free(fileBuf);
-			g_object_unref(rsvgh);
-			return NULL;
-		} 
-
-		free(fileBuf);
-
-		rsvg_handle_close(rsvgh, &err);
 		rsvg_handle_set_dpi(rsvgh, POINTS_PER_INCH);
 
                 break;
+            }
             default:
                 rsvgh = NULL;
         }
@@ -136,7 +106,13 @@ static void gvloadimage_rsvg_cairo(GVJ_t * job, usershape_t *us, boxf b, bool fi
         cairo_set_source_surface(cr, surface, 0, 0);
 	cairo_translate(cr, b.LL.x, -b.UR.y);
 	cairo_scale(cr, (b.UR.x - b.LL.x) / us->w, (b.UR.y - b.LL.y) / us->h);
+#if LIBRSVG_MAJOR_VERSION > 2 || (LIBRSVG_MAJOR_VERSION == 2 && LIBRSVG_MINOR_VERSION >= 46)
+	const RsvgRectangle viewport = {.width = b.UR.x - b.LL.x,
+	                                .height = b.UR.y - b.LL.y};
+	rsvg_handle_render_document(rsvgh, cr, &viewport, NULL);
+#else
 	rsvg_handle_render_cairo(rsvgh, cr);
+#endif
 
         cairo_paint (cr);
         cairo_restore(cr);
@@ -146,14 +122,8 @@ static void gvloadimage_rsvg_cairo(GVJ_t * job, usershape_t *us, boxf b, bool fi
 static gvloadimage_engine_t engine_cairo = {
     gvloadimage_rsvg_cairo
 };
-#endif
-#endif
 
 gvplugin_installed_t gvloadimage_rsvg_types[] = {
-#ifdef HAVE_PANGOCAIRO
-#ifdef HAVE_RSVG
     {FORMAT_SVG_CAIRO, "svg:cairo", 1, &engine_cairo, NULL},
-#endif
-#endif
     {0, NULL, 0, NULL, NULL}
 };
