@@ -4,10 +4,12 @@
 example usage of the Graphviz Python module
 """
 
-import gv  # pylint: disable=import-error
+import gv
 
 
-def main():  # pylint: disable=missing-function-docstring
+def main():
+    """entry point"""
+
     # create a new empty graph
     G = gv.digraph("G")
     # define a simple graph ( A->B )
