@@ -49,7 +49,7 @@ public:
   void set_stroke(std::string_view stroke) override;
   void set_stroke_opacity(double stroke_opacity) override;
   void set_stroke_width(double stroke_width) override;
-  void set_point(std::pair<double, double> point) override;
+  void set_point(std::pair<double, double> pt) override;
   void set_text(std::string_view text) override;
   void set_text_anchor(std::string_view text_anchor) override;
   void set_transform(double a, double b, double c, double d, double e,
@@ -58,6 +58,16 @@ public:
   void set_width(double width) override;
   void set_x(double x) override;
   void set_y(double y) override;
+  /// Add SVG `rect` elements representing the bounding boxes of nodes and edges
+  /// to the corresponding `g` elements
+  void add_bboxes();
+  /// Add SVG rects showing the overlap between the outline bounding boxes of
+  /// each node and edge (with penwidth taken into account)
+  void add_node_edge_outline_bbox_overlaps(double tolerance = 0);
+  /// Add SVG `rect` elements representing the outline bounding boxes of nodes
+  /// and edges to the corresponding `g` elements. The outline bounding box is
+  /// the bounding box with penwidth taken into account.
+  void add_outline_bboxes();
   /// Create an SVGAnalyzer from DOT source using the `engine` layout engine.
   ///
   /// \param dot_source The DOT source
