@@ -1,19 +1,19 @@
+#include <format>
 #include <iostream>
 #include <string>
 
-#include <catch2/catch.hpp>
-#include <fmt/format.h>
+#include <catch2/catch_all.hpp>
 
 #include "test_edge_node_overlap_utilities.h"
 #include "test_utilities.h"
 
-TEST_CASE("Overlap ellipse node shapes",
-          "[!shouldfail] Test that an edge connected to an ellipse based node "
-          "touches that node and does not overlap it too much, regardless of "
-          "the node shape") {
+TEST_CASE(
+    "Overlap ellipse node shapes",
+    "Test that an edge connected to an ellipse based node touches that "
+    "node and does not overlap it too much, regardless of the node shape") {
 
   const auto shape = GENERATE_COPY(
-      filter([](const std::string_view shape) { return shape != "point"; },
+      filter([](const std::string_view s) { return s != "point"; },
              from_range(node_shapes_consisting_of_ellipse)));
 
   INFO("Node shape: " << shape);
@@ -29,7 +29,7 @@ TEST_CASE("Overlap ellipse node shapes",
   };
 
   const auto filename_base =
-      fmt::format("{}_{}_rankdir_{}", AUTO_NAME(), shape, rankdir);
+      std::format("{}_{}_rankdir_{}", AUTO_NAME(), shape, rankdir);
 
   test_edge_node_overlap(graph_options, {}, {.filename_base = filename_base});
 }
